RDFCalendar.Parsers.DOMParser

Package RDFCalendar :: Module Parsers :: Class DOMParser |
[show private | hide private]
[frames | no frames]

## Class DOMParser

    A parser which reads resource definitions from DOM documents.

Method Summary
| ``parse`(self, doc, root, store, uriref)` Parse the contents of the given document 'doc', looking for resource information at and below the 'root' element.
| `parse_attribute_values(self, element)`
| ``parse_element`(self, element, store, uriref)` Parse the given 'element', inserting information found within it into the given 'store'.

Method Details

### parse(self, doc, root, store, uriref=None)
    Parse the contents of the given document 'doc', looking for resource
    information at and below the 'root' element. Insert information into the
    given 'store'.

### parse_element(self, element, store, uriref=None)
    Parse the given 'element', inserting information found within it into
    the given 'store'.

Generated by Epydoc 2.1 on Tue Sep 18 23:33:17 2007 | http://epydoc.sf.net